@@ -5,17 +5,17 @@ pages = [
         "nonstiff/basic_methods.md",
         "nonstiff/sra_sri_methods.md",
         "nonstiff/high_weak_order.md",
-        "nonstiff/commutative_noise.md"
+        "nonstiff/commutative_noise.md",
     ],
     "Stiff Solvers" => [
         "stiff/implicit_methods.md",
         "stiff/split_step_methods.md",
-        "stiff/stabilized_methods.md"
+        "stiff/stabilized_methods.md",
     ],
     "Jump Diffusion" => [
-        "jumpdiffusion/tau_leaping.md"
+        "jumpdiffusion/tau_leaping.md",
     ],
     "Misc Solvers" => [
-        "misc.md"
-    ]
+        "misc.md",
+    ],
 ]
