@@ -1,55 +1,78 @@
 ## SciMLBase Trait Definitions
 
-function SciMLBase.isautodifferentiable(alg::Union{
-        StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
-        StochasticDiffEqJumpAlgorithm})
-    true
+function SciMLBase.isautodifferentiable(
+        alg::Union{
+            StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
+            StochasticDiffEqJumpAlgorithm,
+        }
+    )
+    return true
 end
-function SciMLBase.allows_arbitrary_number_types(alg::Union{
-        StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
-        StochasticDiffEqJumpAlgorithm})
-    true
+function SciMLBase.allows_arbitrary_number_types(
+        alg::Union{
+            StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
+            StochasticDiffEqJumpAlgorithm,
+        }
+    )
+    return true
 end
-function SciMLBase.allowscomplex(alg::Union{
-        StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
-        StochasticDiffEqJumpAlgorithm})
-    true
+function SciMLBase.allowscomplex(
+        alg::Union{
+            StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
+            StochasticDiffEqJumpAlgorithm,
+        }
+    )
+    return true
 end
 SciMLBase.isdiscrete(alg::StochasticDiffEqJumpAlgorithm) = true
 
-function SciMLBase.forwarddiffs_model(alg::Union{StochasticDiffEqNewtonAlgorithm,
-        StochasticDiffEqNewtonAdaptiveAlgorithm, StochasticDiffEqJumpNewtonAdaptiveAlgorithm,
-        StochasticDiffEqJumpNewtonDiffusionAdaptiveAlgorithm})
-    OrdinaryDiffEqCore.alg_autodiff(alg)
+function SciMLBase.forwarddiffs_model(
+        alg::Union{
+            StochasticDiffEqNewtonAlgorithm,
+            StochasticDiffEqNewtonAdaptiveAlgorithm, StochasticDiffEqJumpNewtonAdaptiveAlgorithm,
+            StochasticDiffEqJumpNewtonDiffusionAdaptiveAlgorithm,
+        }
+    )
+    return OrdinaryDiffEqCore.alg_autodiff(alg)
 end
 
 # Required for initialization, because ODECore._initialize_dae! calls it during
 # OverrideInit
-function OrdinaryDiffEqCore.has_autodiff(::Union{
-        StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
-        StochasticDiffEqJumpAlgorithm})
-    false
+function OrdinaryDiffEqCore.has_autodiff(
+        ::Union{
+            StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
+            StochasticDiffEqJumpAlgorithm,
+        }
+    )
+    return false
 end
 for T in [
-    StochasticDiffEqNewtonAlgorithm, StochasticDiffEqNewtonAdaptiveAlgorithm,
-    StochasticDiffEqJumpNewtonAdaptiveAlgorithm,
-    StochasticDiffEqJumpNewtonDiffusionAdaptiveAlgorithm]
+        StochasticDiffEqNewtonAlgorithm, StochasticDiffEqNewtonAdaptiveAlgorithm,
+        StochasticDiffEqJumpNewtonAdaptiveAlgorithm,
+        StochasticDiffEqJumpNewtonDiffusionAdaptiveAlgorithm,
+    ]
     @eval OrdinaryDiffEqCore.has_autodiff(::$T) = true
 end
 
 _alg_autodiff(::StochasticDiffEqNewtonAlgorithm{T, AD}) where {T, AD} = Val{AD}()
 _alg_autodiff(::StochasticDiffEqNewtonAdaptiveAlgorithm{T, AD}) where {T, AD} = Val{AD}()
 function _alg_autodiff(::StochasticDiffEqJumpNewtonAdaptiveAlgorithm{T, AD}) where {T, AD}
-    Val{AD}()
+    return Val{AD}()
 end
-function _alg_autodiff(::StochasticDiffEqJumpNewtonDiffusionAdaptiveAlgorithm{
-        T, AD}) where {T, AD}
-    Val{AD}()
+function _alg_autodiff(
+        ::StochasticDiffEqJumpNewtonDiffusionAdaptiveAlgorithm{
+            T, AD,
+        }
+    ) where {T, AD}
+    return Val{AD}()
 end
 _alg_autodiff(alg::StochasticCompositeAlgorithm) = _alg_autodiff(alg.algs[end])
 
-function OrdinaryDiffEqCore.alg_autodiff(alg::Union{
-        StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm})
+function OrdinaryDiffEqCore.alg_autodiff(
+        alg::Union{
+            StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
+        }
+    )
     ad = _alg_autodiff(alg)
     if ad == Val(false)
         return ADTypes.AutoFiniteDiff()
@@ -61,29 +84,38 @@ function OrdinaryDiffEqCore.alg_autodiff(alg::Union{
 end
 
 isadaptive(alg::Union{StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm}) = false
-function isadaptive(alg::Union{
-        StochasticDiffEqAdaptiveAlgorithm, StochasticDiffEqRODEAdaptiveAlgorithm,
-        StochasticDiffEqJumpAdaptiveAlgorithm,
-        StochasticDiffEqJumpDiffusionAdaptiveAlgorithm})
-    true
+function isadaptive(
+        alg::Union{
+            StochasticDiffEqAdaptiveAlgorithm, StochasticDiffEqRODEAdaptiveAlgorithm,
+            StochasticDiffEqJumpAdaptiveAlgorithm,
+            StochasticDiffEqJumpDiffusionAdaptiveAlgorithm,
+        }
+    )
+    return true
 end
-function isadaptive(alg::Union{
-        StochasticDiffEqCompositeAlgorithm, StochasticDiffEqRODECompositeAlgorithm})
-    all(isadaptive.(alg.algs))
+function isadaptive(
+        alg::Union{
+            StochasticDiffEqCompositeAlgorithm, StochasticDiffEqRODECompositeAlgorithm,
+        }
+    )
+    return all(isadaptive.(alg.algs))
 end
-function isadaptive(prob, alg::Union{
-        StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm})
-    isadaptive(alg)
+function isadaptive(
+        prob, alg::Union{
+            StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
+        }
+    )
+    return isadaptive(alg)
 end
 isadaptive(prob::JumpProblem, alg::ImplicitEM) = false
 
 ## StochasticDiffEq Internal Traits
 
 function qmax_default(alg::Union{StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm})
-    isadaptive(alg) ? 9 // 8 : 0
+    return isadaptive(alg) ? 9 // 8 : 0
 end
 function qmin_default(alg::Union{StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm})
-    isadaptive(alg) ? 1 // 5 : 0
+    return isadaptive(alg) ? 1 // 5 : 0
 end
 
 delta_default(alg) = 1 // 1
@@ -91,23 +123,32 @@ delta_default(alg::SRIW1) = 1 // 6
 
 ispredictive(alg::Union{StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm}) = false
 isstandard(alg::Union{StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm}) = false
-function qsteady_min_default(alg::Union{
-        StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm})
-    1
+function qsteady_min_default(
+        alg::Union{
+            StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
+        }
+    )
+    return 1
 end
-function qsteady_max_default(alg::Union{
-        StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm})
-    1
+function qsteady_max_default(
+        alg::Union{
+            StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
+        }
+    )
+    return 1
 end
 
 # special cases in stepsize_controllers.jl
-function default_controller(alg::Union{TauLeaping, CaoTauLeaping}, args...)
-    DummyController()
+function default_controller(
+        alg::Union{TauLeaping, CaoTauLeaping, ThetaTrapezoidalTauLeaping}, args...
+    )
+    return DummyController()
 end
 
 # For whether an algorithm uses a priori dt estimates or utilizes an error estimate
 isaposteriori(alg) = false
 isaposteriori(alg::CaoTauLeaping) = true
+isaposteriori(alg::ThetaTrapezoidalTauLeaping) = false
 
 alg_order(alg::EM) = 1 // 2
 alg_order(alg::LambaEM) = 1 // 2
@@ -191,65 +232,80 @@ alg_order(alg::SMEB) = 1 // 1
 
 alg_order(alg::TauLeaping) = 1 // 1
 alg_order(alg::CaoTauLeaping) = 1 // 1
+alg_order(alg::ImplicitTauLeaping) = 1 // 1  # Weak first order (backward Euler)
+alg_order(alg::ThetaTrapezoidalTauLeaping) = 2 // 1  # Weak second order
 
 alg_order(alg::BAOAB) = 1 // 1
 
 alg_order(alg::SKenCarp) = 2 // 1
-function alg_order(alg::Union{
-        StochasticDiffEqCompositeAlgorithm, StochasticDiffEqRODECompositeAlgorithm})
-    maximum(alg_order.(alg.algs))
+function alg_order(
+        alg::Union{
+            StochasticDiffEqCompositeAlgorithm, StochasticDiffEqRODECompositeAlgorithm,
+        }
+    )
+    return maximum(alg_order.(alg.algs))
 end
 get_current_alg_order(alg::StochasticDiffEqAlgorithm, cache) = alg_order(alg)
 function get_current_alg_order(
         alg::Union{
-            StochasticDiffEqCompositeAlgorithm, StochasticDiffEqRODECompositeAlgorithm},
-        cache)
-    alg_order(alg.algs[cache.current])
+            StochasticDiffEqCompositeAlgorithm, StochasticDiffEqRODECompositeAlgorithm,
+        },
+        cache
+    )
+    return alg_order(alg.algs[cache.current])
 end
 
 function beta2_default(alg::Union{StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm})
-    isadaptive(alg) ? 2 // (5alg_order(alg)) : 0
+    return isadaptive(alg) ? 2 // (5alg_order(alg)) : 0
 end
 function beta1_default(alg::Union{StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm}, beta2)
-    isadaptive(alg) ? 7 // (10alg_order(alg)) : 0
+    return isadaptive(alg) ? 7 // (10alg_order(alg)) : 0
 end
 
 isdtchangeable(alg::Union{StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm}) = true
 
 function SciMLBase.alg_interpretation(alg::StochasticDiffEqAlgorithm)
-    SciMLBase.AlgorithmInterpretation.Ito
+    return SciMLBase.AlgorithmInterpretation.Ito
 end
 function SciMLBase.alg_interpretation(alg::EulerHeun)
-    SciMLBase.AlgorithmInterpretation.Stratonovich
+    return SciMLBase.AlgorithmInterpretation.Stratonovich
 end
 function SciMLBase.alg_interpretation(alg::LambaEulerHeun)
-    SciMLBase.AlgorithmInterpretation.Stratonovich
+    return SciMLBase.AlgorithmInterpretation.Stratonovich
 end
 function SciMLBase.alg_interpretation(alg::KomBurSROCK2)
-    SciMLBase.AlgorithmInterpretation.Stratonovich
+    return SciMLBase.AlgorithmInterpretation.Stratonovich
 end
 function SciMLBase.alg_interpretation(alg::RKMil{interpretation}) where {interpretation}
-    interpretation
+    return interpretation
 end
-function SciMLBase.alg_interpretation(alg::SROCK1{
-        interpretation, E}) where {interpretation, E}
-    interpretation
+function SciMLBase.alg_interpretation(
+        alg::SROCK1{
+            interpretation, E,
+        }
+    ) where {interpretation, E}
+    return interpretation
 end
 SciMLBase.alg_interpretation(alg::RKMilCommute) = alg.interpretation
 SciMLBase.alg_interpretation(alg::RKMilGeneral) = alg.interpretation
-function SciMLBase.alg_interpretation(alg::ImplicitRKMil{CS,
-        AD,
-        F,
-        P,
-        FDT,
-        ST,
-        CJ,
-        N,
-        T2,
-        Controller,
-        interpretation}) where {
-        CS, AD, F, P, FDT, ST, CJ, N, T2, Controller, interpretation}
-    interpretation
+function SciMLBase.alg_interpretation(
+        alg::ImplicitRKMil{
+            CS,
+            AD,
+            F,
+            P,
+            FDT,
+            ST,
+            CJ,
+            N,
+            T2,
+            Controller,
+            interpretation,
+        }
+    ) where {
+        CS, AD, F, P, FDT, ST, CJ, N, T2, Controller, interpretation,
+    }
+    return interpretation
 end
 
 SciMLBase.alg_interpretation(alg::RS1) = SciMLBase.AlgorithmInterpretation.Stratonovich
@@ -259,14 +315,17 @@ SciMLBase.alg_interpretation(alg::NON) = SciMLBase.AlgorithmInterpretation.Strat
 SciMLBase.alg_interpretation(alg::COM) = SciMLBase.AlgorithmInterpretation.Stratonovich
 SciMLBase.alg_interpretation(alg::NON2) = SciMLBase.AlgorithmInterpretation.Stratonovich
 
-function alg_compatible(prob, alg::Union{
-        StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm})
-    true
+function alg_compatible(
+        prob, alg::Union{
+            StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
+        }
+    )
+    return true
 end
 alg_compatible(prob, alg::StochasticDiffEqAlgorithm) = false
 
 function alg_compatible(prob::JumpProblem, alg::StochasticDiffEqAlgorithm)
-    alg_compatible(prob.prob, alg) && prob.regular_jump === nothing &&
+    return alg_compatible(prob.prob, alg) && prob.regular_jump === nothing &&
         prob.prob isa DiffEqBase.AbstractSDEProblem
 end
 alg_compatible(prob::JumpProblem, alg::EM) = alg_compatible(prob.prob, alg)
@@ -332,31 +391,42 @@ alg_compatible(prob::DiffEqBase.AbstractSDEProblem, alg::ISSEulerHeun) = true
 alg_compatible(prob::DiffEqBase.AbstractSDEProblem, alg::SimplifiedEM) = true
 alg_compatible(prob::DiffEqBase.AbstractSDEProblem, alg::RKMil) = is_diagonal_noise(prob)
 function alg_compatible(prob::DiffEqBase.AbstractSDEProblem, alg::ImplicitRKMil)
-    is_diagonal_noise(prob)
+    return is_diagonal_noise(prob)
 end
 alg_compatible(prob::DiffEqBase.AbstractSDEProblem, alg::RKMilCommute) = true # No good check for commutative noise
 alg_compatible(prob::DiffEqBase.AbstractSDEProblem, alg::RKMilGeneral) = true
 alg_compatible(prob::DiffEqBase.AbstractSDEProblem, alg::IIF1M) = true
 alg_compatible(prob::DiffEqBase.AbstractSDEProblem, alg::IIF2M) = true
-function alg_compatible(prob::DiffEqBase.AbstractSDEProblem,
+function alg_compatible(
+        prob::DiffEqBase.AbstractSDEProblem,
         alg::Union{
-            StochasticDiffEqCompositeAlgorithm, StochasticDiffEqRODECompositeAlgorithm})
-    max((alg_compatible(prob, a) for a in alg.algs)...)
+            StochasticDiffEqCompositeAlgorithm, StochasticDiffEqRODECompositeAlgorithm,
+        }
+    )
+    return max((alg_compatible(prob, a) for a in alg.algs)...)
 end
 alg_compatible(prob::DiffEqBase.AbstractSDEProblem, alg::BAOAB) = is_diagonal_noise(prob)
 
-function alg_compatible(prob::JumpProblem,
-        alg::Union{StochasticDiffEqJumpAdaptiveAlgorithm, StochasticDiffEqJumpAlgorithm})
-    prob.prob isa DiscreteProblem
+function alg_compatible(
+        prob::JumpProblem,
+        alg::Union{StochasticDiffEqJumpAdaptiveAlgorithm, StochasticDiffEqJumpAlgorithm}
+    )
+    return prob.prob isa DiscreteProblem
 end
 
-function alg_needs_extra_process(alg::Union{
-        StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm})
-    false
+function alg_needs_extra_process(
+        alg::Union{
+            StochasticDiffEqAlgorithm, StochasticDiffEqRODEAlgorithm,
+        }
+    )
+    return false
 end
-function alg_needs_extra_process(alg::Union{
-        StochasticDiffEqCompositeAlgorithm, StochasticDiffEqRODECompositeAlgorithm})
-    max((alg_needs_extra_process(a) for a in alg.algs)...)
+function alg_needs_extra_process(
+        alg::Union{
+            StochasticDiffEqCompositeAlgorithm, StochasticDiffEqRODECompositeAlgorithm,
+        }
+    )
+    return max((alg_needs_extra_process(a) for a in alg.algs)...)
 end
 alg_needs_extra_process(alg::RKMilGeneral) = true
 alg_needs_extra_process(alg::SRI) = true
@@ -387,70 +457,108 @@ alg_needs_extra_process(alg::PL1WM) = true
 alg_needs_extra_process(alg::NON) = true
 alg_needs_extra_process(alg::NON2) = true
 
-function OrdinaryDiffEqDifferentiation._alg_autodiff(alg::StochasticDiffEqNewtonAlgorithm{
-        CS, AD, FDT, ST, CJ, Controller}) where {CS, AD, FDT, ST, CJ, Controller}
-    Val{AD}()
+function OrdinaryDiffEqDifferentiation._alg_autodiff(
+        alg::StochasticDiffEqNewtonAlgorithm{
+            CS, AD, FDT, ST, CJ, Controller,
+        }
+    ) where {CS, AD, FDT, ST, CJ, Controller}
+    return Val{AD}()
 end
-function OrdinaryDiffEqDifferentiation._alg_autodiff(alg::StochasticDiffEqNewtonAdaptiveAlgorithm{
-        CS, AD, FDT, ST, CJ, Controller}) where {CS, AD, FDT, ST, CJ, Controller}
-    Val{AD}()
+function OrdinaryDiffEqDifferentiation._alg_autodiff(
+        alg::StochasticDiffEqNewtonAdaptiveAlgorithm{
+            CS, AD, FDT, ST, CJ, Controller,
+        }
+    ) where {CS, AD, FDT, ST, CJ, Controller}
+    return Val{AD}()
 end
-function OrdinaryDiffEqDifferentiation._alg_autodiff(alg::StochasticDiffEqJumpNewtonAdaptiveAlgorithm{
-        CS, AD, FDT, ST, CJ, Controller}) where {CS, AD, FDT, ST, CJ, Controller}
-    Val{AD}()
+function OrdinaryDiffEqDifferentiation._alg_autodiff(
+        alg::StochasticDiffEqJumpNewtonAdaptiveAlgorithm{
+            CS, AD, FDT, ST, CJ, Controller,
+        }
+    ) where {CS, AD, FDT, ST, CJ, Controller}
+    return Val{AD}()
 end
-function OrdinaryDiffEqDifferentiation._alg_autodiff(alg::StochasticDiffEqJumpNewtonDiffusionAdaptiveAlgorithm{
-        CS, AD, FDT, ST, CJ, Controller}) where {CS, AD, FDT, ST, CJ, Controller}
-    Val{AD}()
+function OrdinaryDiffEqDifferentiation._alg_autodiff(
+        alg::StochasticDiffEqJumpNewtonDiffusionAdaptiveAlgorithm{
+            CS, AD, FDT, ST, CJ, Controller,
+        }
+    ) where {CS, AD, FDT, ST, CJ, Controller}
+    return Val{AD}()
 end
 
 function OrdinaryDiffEqCore.get_current_alg_autodiff(alg::StochasticDiffEqCompositeAlgorithm, cache)
-    OrdinaryDiffEqCore.alg_autodiff(alg.algs[cache.current])
+    return OrdinaryDiffEqCore.alg_autodiff(alg.algs[cache.current])
 end
 
-function OrdinaryDiffEqCore.get_chunksize(alg::StochasticDiffEqNewtonAlgorithm{
-        CS, AD, FDT, ST, CJ, Controller}) where {CS, AD, FDT, ST, CJ, Controller}
-    Val(CS)
+function OrdinaryDiffEqCore.get_chunksize(
+        alg::StochasticDiffEqNewtonAlgorithm{
+            CS, AD, FDT, ST, CJ, Controller,
+        }
+    ) where {CS, AD, FDT, ST, CJ, Controller}
+    return Val(CS)
 end
-function OrdinaryDiffEqCore.get_chunksize(alg::StochasticDiffEqNewtonAdaptiveAlgorithm{
-        CS, AD, FDT, ST, CJ, Controller}) where {CS, AD, FDT, ST, CJ, Controller}
-    Val(CS)
+function OrdinaryDiffEqCore.get_chunksize(
+        alg::StochasticDiffEqNewtonAdaptiveAlgorithm{
+            CS, AD, FDT, ST, CJ, Controller,
+        }
+    ) where {CS, AD, FDT, ST, CJ, Controller}
+    return Val(CS)
 end
-function OrdinaryDiffEqCore.get_chunksize(alg::StochasticDiffEqJumpNewtonAdaptiveAlgorithm{
-        CS, AD, FDT, ST, CJ, Controller}) where {CS, AD, FDT, ST, CJ, Controller}
-    Val(CS)
+function OrdinaryDiffEqCore.get_chunksize(
+        alg::StochasticDiffEqJumpNewtonAdaptiveAlgorithm{
+            CS, AD, FDT, ST, CJ, Controller,
+        }
+    ) where {CS, AD, FDT, ST, CJ, Controller}
+    return Val(CS)
 end
-function OrdinaryDiffEqCore.get_chunksize(alg::StochasticDiffEqJumpNewtonDiffusionAdaptiveAlgorithm{
-        CS, AD, FDT, ST, CJ, Controller}) where {CS, AD, FDT, ST, CJ, Controller}
-    Val(CS)
+function OrdinaryDiffEqCore.get_chunksize(
+        alg::StochasticDiffEqJumpNewtonDiffusionAdaptiveAlgorithm{
+            CS, AD, FDT, ST, CJ, Controller,
+        }
+    ) where {CS, AD, FDT, ST, CJ, Controller}
+    return Val(CS)
 end
 
 @static if isdefined(OrdinaryDiffEqCore, :standardtag)
-    OrdinaryDiffEqCore.standardtag(alg::Union{
-        StochasticDiffEqNewtonAdaptiveAlgorithm{CS, AD, FDT, ST, CJ, Controller},
-        StochasticDiffEqNewtonAlgorithm{CS, AD, FDT, ST, CJ, Controller}}
+    OrdinaryDiffEqCore.standardtag(
+        alg::Union{
+            StochasticDiffEqNewtonAdaptiveAlgorithm{CS, AD, FDT, ST, CJ, Controller},
+            StochasticDiffEqNewtonAlgorithm{CS, AD, FDT, ST, CJ, Controller},
+        }
     ) where {CS, AD, FDT, ST, CJ, Controller} = ST
 end
 
 @static if isdefined(OrdinaryDiffEqCore, :alg_difftype)
-    OrdinaryDiffEqCore.alg_difftype(alg::Union{
-        StochasticDiffEqNewtonAdaptiveAlgorithm{CS, AD, FDT, ST, CJ, Controller},
-        StochasticDiffEqNewtonAlgorithm{CS, AD, FDT, ST, CJ, Controller}}) where {
-        CS, AD, FDT, ST, CJ, Controller} = FDT
+    OrdinaryDiffEqCore.alg_difftype(
+        alg::Union{
+            StochasticDiffEqNewtonAdaptiveAlgorithm{CS, AD, FDT, ST, CJ, Controller},
+            StochasticDiffEqNewtonAlgorithm{CS, AD, FDT, ST, CJ, Controller},
+        }
+    ) where {
+        CS, AD, FDT, ST, CJ, Controller,
+    } = FDT
 end
 
 @static if isdefined(OrdinaryDiffEqCore, :concrete_jac)
-    OrdinaryDiffEqCore.concrete_jac(alg::Union{
-        StochasticDiffEqNewtonAdaptiveAlgorithm{CS, AD, FDT, ST, CJ, Controller},
-        StochasticDiffEqNewtonAlgorithm{CS, AD, FDT, ST, CJ, Controller}}) where {
-        CS, AD, FDT, ST, CJ, Controller} = CJ
+    OrdinaryDiffEqCore.concrete_jac(
+        alg::Union{
+            StochasticDiffEqNewtonAdaptiveAlgorithm{CS, AD, FDT, ST, CJ, Controller},
+            StochasticDiffEqNewtonAlgorithm{CS, AD, FDT, ST, CJ, Controller},
+        }
+    ) where {
+        CS, AD, FDT, ST, CJ, Controller,
+    } = CJ
 end
 
 alg_mass_matrix_compatible(alg::StochasticDiffEqAlgorithm) = false
+alg_mass_matrix_compatible(alg::StochasticDiffEqRODEAlgorithm) = false
 alg_can_repeat_jac(alg::StochasticDiffEqAlgorithm) = true
 
-function alg_mass_matrix_compatible(alg::Union{
-        StochasticDiffEqNewtonAlgorithm, StochasticDiffEqNewtonAdaptiveAlgorithm})
+function alg_mass_matrix_compatible(
+        alg::Union{
+            StochasticDiffEqNewtonAlgorithm, StochasticDiffEqNewtonAdaptiveAlgorithm,
+        }
+    )
     if alg.symplectic
         return true
     elseif alg.theta == 1
@@ -461,8 +569,8 @@ function alg_mass_matrix_compatible(alg::Union{
 end
 
 is_split_step(::StochasticDiffEqAlgorithm) = false
-is_split_step(::EM{split}) = split
-is_split_step(::LambaEM{split}) = split
+is_split_step(::EM{split}) where {split} = split
+is_split_step(::LambaEM{split}) where {split} = split
 
 alg_stability_size(alg::SOSRI2) = 10.6
 alg_stability_size(alg::SOSRA2) = 5.3
@@ -522,4 +630,6 @@ function OrdinaryDiffEqCore.unwrap_alg(integrator::SDEIntegrator, is_stiff)
 end
 
 alg_control_rate(::StochasticDiffEqAlgorithm) = false
+alg_control_rate(::StochasticDiffEqRODEAlgorithm) = false
 alg_control_rate(::TauLeaping) = true
+alg_control_rate(::ThetaTrapezoidalTauLeaping) = true  # We manage rates manually
