@@ -8,7 +8,8 @@ mutable struct StochasticCompositeCache{T, F} <: StochasticDiffEqCache
     current::Int
 end
 
-function alg_cache(alg::algType,
+function alg_cache(
+        alg::algType,
         prob,
         u,
         ΔW,
@@ -24,12 +25,18 @@ function alg_cache(alg::algType,
         f,
         t,
         dt,
-        ::Type{Val{T}}) where {T, algType <: StochasticCompositeAlgorithm,
-        uEltypeNoUnits, uBottomEltypeNoUnits, tTypeNoUnits}
+        ::Type{Val{T}}
+    ) where {
+        T, algType <: StochasticCompositeAlgorithm,
+        uEltypeNoUnits, uBottomEltypeNoUnits, tTypeNoUnits,
+    }
     caches = map(
-        (x)->alg_cache(x, prob, u, ΔW, ΔZ, p, rate_prototype, noise_rate_prototype,
+        (x) -> alg_cache(
+            x, prob, u, ΔW, ΔZ, p, rate_prototype, noise_rate_prototype,
             jump_rate_prototype, uEltypeNoUnits, uBottomEltypeNoUnits,
-            tTypeNoUnits, uprev, f, t, dt, Val{T}),
-        alg.algs)
-    StochasticCompositeCache(caches, alg.choice_function, 1)
+            tTypeNoUnits, uprev, f, t, dt, Val{T}
+        ),
+        alg.algs
+    )
+    return StochasticCompositeCache(caches, alg.choice_function, 1)
 end
