@@ -1,7 +1,7 @@
 ## Extrapolations are currently just constant
 
 function sde_extrapolant!(out, Θ, integrator::DEIntegrator, idxs, deriv::Type)
-    if idxs === nothing
+    return if idxs === nothing
         recursivecopy!(out, integrator.u)
     else
         out[idxs] .= @view integrator.u[idxs]
@@ -17,97 +17,98 @@ function sde_extrapolant(Θ, integrator::DEIntegrator, idxs, deriv::Type)
 end
 
 function sde_interpolant!(out, Θ, integrator::DEIntegrator, idxs, deriv::Type)
-    sde_interpolant!(out, Θ, integrator.dt, integrator.uprev, integrator.u, idxs, deriv)
+    return sde_interpolant!(out, Θ, integrator.dt, integrator.uprev, integrator.u, idxs, deriv)
 end
 
 function sde_interpolant(Θ, integrator::DEIntegrator, idxs, deriv::Type{T}) where {T}
-    sde_interpolant(Θ, integrator.dt, integrator.uprev, integrator.u, idxs, deriv)
+    return sde_interpolant(Θ, integrator.dt, integrator.uprev, integrator.u, idxs, deriv)
 end
 
 @muladd function sde_interpolant(Θ, dt, u0, u1, idxs::Nothing, deriv::Type{Val{0}})
-    @.. (1-Θ)*u0 + Θ*u1
+    @.. (1 - Θ) * u0 + Θ * u1
 end
 
 @muladd function sde_interpolant(Θ, dt, u0, u1, idxs, deriv::Type{Val{0}})
-    @.. (1-Θ)*u0[idxs] + Θ*u1[idxs]
+    @.. (1 - Θ) * u0[idxs] + Θ * u1[idxs]
 end
 
 function sde_interpolant(Θ, dt, u0, u1, idxs::Nothing, deriv::Type{Val{1}})
-    @.. (u1-u0)/dt
+    return @.. (u1 - u0) / dt
 end
 
 function sde_interpolant(Θ, dt, u0, u1, idxs, deriv::Type{Val{1}})
-    @.. (u1[idxs]-u0[idxs])/dt
+    return @.. (u1[idxs] - u0[idxs]) / dt
 end
 
 @muladd function sde_interpolant!(out, Θ, dt, u0, u1, idxs, deriv::Type{Val{0}})
-    Θm1 = (1-Θ)
+    Θm1 = (1 - Θ)
     if idxs === nothing
-        @.. out = Θm1*u0 + Θ*u1
+        @.. out = Θm1 * u0 + Θ * u1
     else
-        @views @.. out = Θm1*u0[idxs] + Θ*u1[idxs]
+        @views @.. out = Θm1 * u0[idxs] + Θ * u1[idxs]
     end
 end
 
 function sde_interpolant!(out, Θ, dt, u0, u1, idxs, deriv::Type{Val{1}})
-    if idxs === nothing
-        @.. out = (u1-u0)/dt
+    return if idxs === nothing
+        @.. out = (u1 - u0) / dt
     else
-        @views @.. out = (u1[idxs]-u0[idxs])/dt
+        @views @.. out = (u1[idxs] - u0[idxs]) / dt
     end
 end
 
 @inline function current_interpolant(t::Number, integrator::DEIntegrator, idxs, deriv)
-    Θ = (t-integrator.tprev)/integrator.dt
-    sde_interpolant(Θ, integrator, idxs, deriv)
+    Θ = (t - integrator.tprev) / integrator.dt
+    return sde_interpolant(Θ, integrator, idxs, deriv)
 end
 
 @inline function current_interpolant(t, integrator::DEIntegrator, idxs, deriv)
     Θ = (t .- integrator.tprev) ./ integrator.dt
-    [sde_interpolant(ϕ, integrator, idxs, deriv) for ϕ in Θ]
+    return [sde_interpolant(ϕ, integrator, idxs, deriv) for ϕ in Θ]
 end
 
 @inline function current_interpolant!(val, t::Number, integrator::DEIntegrator, idxs, deriv)
-    Θ = (t-integrator.tprev)/integrator.dt
-    sde_interpolant!(val, Θ, integrator, idxs, deriv)
+    Θ = (t - integrator.tprev) / integrator.dt
+    return sde_interpolant!(val, Θ, integrator, idxs, deriv)
 end
 
 @inline function current_interpolant!(val, t, integrator::DEIntegrator, idxs, deriv)
     Θ = (t .- integrator.tprev) ./ integrator.dt
-    [sde_interpolant!(val, ϕ, integrator, idxs, deriv) for ϕ in Θ]
+    return [sde_interpolant!(val, ϕ, integrator, idxs, deriv) for ϕ in Θ]
 end
 
 @inline function current_extrapolant(t::Number, integrator::DEIntegrator, idxs = nothing, deriv = Val{0})
-    Θ = (t-integrator.tprev)/(integrator.t-integrator.tprev)
-    sde_extrapolant(Θ, integrator, idxs, deriv)
+    Θ = (t - integrator.tprev) / (integrator.t - integrator.tprev)
+    return sde_extrapolant(Θ, integrator, idxs, deriv)
 end
 
 @inline function current_extrapolant!(
-        val, t::Number, integrator::DEIntegrator, idxs = nothing, deriv = Val{0})
-    Θ = (t-integrator.tprev)/(integrator.t-integrator.tprev)
-    sde_extrapolant!(val, Θ, integrator, idxs, deriv)
+        val, t::Number, integrator::DEIntegrator, idxs = nothing, deriv = Val{0}
+    )
+    Θ = (t - integrator.tprev) / (integrator.t - integrator.tprev)
+    return sde_extrapolant!(val, Θ, integrator, idxs, deriv)
 end
 
 @inline function current_extrapolant(t::AbstractArray, integrator::DEIntegrator, idxs = nothing, deriv = Val{0})
-    Θ = (t .- integrator.tprev) ./ (integrator.t-integrator.tprev)
-    [sde_extrapolant(ϕ, integrator, idxs, deriv) for ϕ in Θ]
+    Θ = (t .- integrator.tprev) ./ (integrator.t - integrator.tprev)
+    return [sde_extrapolant(ϕ, integrator, idxs, deriv) for ϕ in Θ]
 end
 
-@inline function current_extrapolant!(val, t, integrator::DEIntegrator, idxs =  nothingderiv=Val{0} )
-    Θ = (t .- integrator.tprev) ./ (integrator.t-integrator.tprev)
-    [sde_extrapolant!(val, ϕ, integrator, idxs, deriv) for ϕ in Θ]
+@inline function current_extrapolant!(val, t, integrator::DEIntegrator, idxs = nothingderiv = Val{0})
+    Θ = (t .- integrator.tprev) ./ (integrator.t - integrator.tprev)
+    return [sde_extrapolant!(val, ϕ, integrator, idxs, deriv) for ϕ in Θ]
 end
 
 """
-sde_interpolation(tvals,ts,timeseries,ks)
+    sde_interpolation(tvals,ts,timeseries,ks)
 
 Get the value at tvals where the solution is known at the
 times ts (sorted), with values timeseries and derivatives ks
 """
 function sde_interpolation(tvals, id, idxs, deriv, p, continuity::Symbol = :left)
     (; ts, timeseries) = id
-    @inbounds tdir = sign(ts[end]-ts[1])
-    idx = sortperm(tvals, rev = tdir<0)
+    @inbounds tdir = sign(ts[end] - ts[1])
+    idx = sortperm(tvals, rev = tdir < 0)
 
     # start the search thinking it's ts[1]-ts[2]
     i₋ = 1
@@ -119,8 +120,12 @@ function sde_interpolation(tvals, id, idxs, deriv, p, continuity::Symbol = :left
             if continuity === :left
                 # we have i₋ = i₊ = 1 if t = ts[1], i₊ = i₋ + 1 = lastindex(ts) if t > ts[end],
                 # and otherwise i₋ and i₊ satisfy ts[i₋] < t ≤ ts[i₊]
-                i₊ = min(lastindex(ts), OrdinaryDiffEqCore._searchsortedfirst(ts, t, i₊, tdir >
-                                                                                         0))
+                i₊ = min(
+                    lastindex(ts), OrdinaryDiffEqCore._searchsortedfirst(
+                        ts, t, i₊, tdir >
+                            0
+                    )
+                )
                 i₋ = i₊ > 1 ? i₊ - 1 : i₊
             else
                 # we have i₋ = i₊ - 1 = 1 if t < ts[1], i₊ = i₋ = lastindex(ts) if t = ts[end],
@@ -130,34 +135,38 @@ function sde_interpolation(tvals, id, idxs, deriv, p, continuity::Symbol = :left
             end
 
             dt = ts[i₊] - ts[i₋]
-            Θ = iszero(dt) ? oneunit(t) / oneunit(dt) : (t-ts[i₋]) / dt
+            Θ = iszero(dt) ? oneunit(t) / oneunit(dt) : (t - ts[i₋]) / dt
 
             sde_interpolant(Θ, dt, timeseries[i₋], timeseries[i₊], idxs, deriv)
         end
     end
 
-    if tdir<0
+    if tdir < 0
         permute!(vals, idx)
     end
 
-    DiffEqArray(vals, tvals)
+    return DiffEqArray(vals, tvals)
 end
 
 """
-sde_interpolation(tval::Number,ts,timeseries,ks)
+    sde_interpolation(tval::Number,ts,timeseries,ks)
 
 Get the value at tval where the solution is known at the
 times ts (sorted), with values timeseries and derivatives ks
 """
 function sde_interpolation(tval::Number, id, idxs, deriv, p, continuity::Symbol = :left)
     (; ts, timeseries) = id
-    @inbounds tdir = sign(ts[end]-ts[1])
+    @inbounds tdir = sign(ts[end] - ts[1])
 
     if continuity === :left
         # we have i₋ = i₊ = 1 if tval = ts[1], i₊ = i₋ + 1 = lastindex(ts) if tval > ts[end],
         # and otherwise i₋ and i₊ satisfy ts[i₋] < tval ≤ ts[i₊]
-        i₊ = min(lastindex(ts), OrdinaryDiffEqCore._searchsortedfirst(ts, tval, 2, tdir >
-                                                                                   0))
+        i₊ = min(
+            lastindex(ts), OrdinaryDiffEqCore._searchsortedfirst(
+                ts, tval, 2, tdir >
+                    0
+            )
+        )
         i₋ = i₊ > 1 ? i₊ - 1 : i₊
     else
         # we have i₋ = i₊ - 1 = 1 if tval < ts[1], i₊ = i₋ = lastindex(ts) if tval = ts[end],
@@ -168,23 +177,28 @@ function sde_interpolation(tval::Number, id, idxs, deriv, p, continuity::Symbol
 
     @inbounds begin
         dt = ts[i₊] - ts[i₋]
-        Θ = iszero(dt) ? oneunit(tval) / oneunit(dt) : (tval-ts[i₋]) / dt
+        Θ = iszero(dt) ? oneunit(tval) / oneunit(dt) : (tval - ts[i₋]) / dt
         val = sde_interpolant(Θ, dt, timeseries[i₋], timeseries[i₊], idxs, deriv)
     end
 
-    val
+    return val
 end
 
 function sde_interpolation!(
-        out, tval::Number, id, idxs, deriv, p, continuity::Symbol = :left)
+        out, tval::Number, id, idxs, deriv, p, continuity::Symbol = :left
+    )
     (; ts, timeseries) = id
-    @inbounds tdir = sign(ts[end]-ts[1])
+    @inbounds tdir = sign(ts[end] - ts[1])
 
     if continuity === :left
         # we have i₋ = i₊ = 1 if tval = ts[1], i₊ = i₋ + 1 = lastindex(ts) if tval > ts[end],
         # and otherwise i₋ and i₊ satisfy ts[i₋] < tval ≤ ts[i₊]
-        i₊ = min(lastindex(ts), OrdinaryDiffEqCore._searchsortedfirst(ts, tval, 2, tdir >
-                                                                                   0))
+        i₊ = min(
+            lastindex(ts), OrdinaryDiffEqCore._searchsortedfirst(
+                ts, tval, 2, tdir >
+                    0
+            )
+        )
         i₋ = i₊ > 1 ? i₊ - 1 : i₊
     else
         # we have i₋ = i₊ - 1 = 1 if tval < ts[1], i₊ = i₋ = lastindex(ts) if tval = ts[end],
@@ -195,17 +209,17 @@ function sde_interpolation!(
 
     @inbounds begin
         dt = ts[i₊] - ts[i₋]
-        Θ = iszero(dt) ? oneunit(tval) / oneunit(dt) : (tval-ts[i₋]) / dt
+        Θ = iszero(dt) ? oneunit(tval) / oneunit(dt) : (tval - ts[i₋]) / dt
         sde_interpolant!(out, Θ, dt, timeseries[i₋], timeseries[i₊], idxs, deriv)
     end
 
-    out
+    return out
 end
 
 function sde_interpolation!(vals, tvals, id, idxs, deriv, p, continuity::Symbol = :left)
     (; ts, timeseries) = id
-    @inbounds tdir = sign(ts[end]-ts[1])
-    idx = sortperm(tvals, rev = tdir<0)
+    @inbounds tdir = sign(ts[end] - ts[1])
+    idx = sortperm(tvals, rev = tdir < 0)
 
     # start the search thinking it's in ts[1]-ts[2]
     i₋ = 1
@@ -216,8 +230,12 @@ function sde_interpolation!(vals, tvals, id, idxs, deriv, p, continuity::Symbol
         if continuity === :left
             # we have i₋ = i₊ = 1 if t = ts[1], i₊ = i₋ + 1 = lastindex(ts) if t > ts[end],
             # and otherwise i₋ and i₊ satisfy ts[i₋] < t ≤ ts[i₊]
-            i₊ = min(lastindex(ts), OrdinaryDiffEqCore._searchsortedfirst(ts, t, i₊, tdir >
-                                                                                     0))
+            i₊ = min(
+                lastindex(ts), OrdinaryDiffEqCore._searchsortedfirst(
+                    ts, t, i₊, tdir >
+                        0
+                )
+            )
             i₋ = i₊ > 1 ? i₊ - 1 : i₊
         else
             # we have i₋ = i₊ - 1 = 1 if t < ts[1], i₊ = i₋ = lastindex(ts) if t = ts[end],
@@ -227,7 +245,7 @@ function sde_interpolation!(vals, tvals, id, idxs, deriv, p, continuity::Symbol
         end
 
         dt = ts[i₊] - ts[i₋]
-        Θ = iszero(dt) ? oneunit(t) / oneunit(dt) : (t-ts[i₋]) / dt
+        Θ = iszero(dt) ? oneunit(t) / oneunit(dt) : (t - ts[i₋]) / dt
 
         if eltype(vals) <: AbstractArray
             sde_interpolant!(vals[j], Θ, dt, timeseries[i₋], timeseries[i₊], idxs, deriv)
@@ -236,5 +254,5 @@ function sde_interpolation!(vals, tvals, id, idxs, deriv, p, continuity::Symbol
         end
     end
 
-    vals
+    return vals
 end
