@@ -22,73 +22,76 @@ mutable struct JCommute_iip{JType} <: AbstractJCommute
     J::JType
     function JCommute_iip(ΔW)
         J = false .* vec(ΔW) .* vec(ΔW)'
-        new{typeof(J)}(J)
+        return new{typeof(J)}(J)
     end
 end
 
-function get_iterated_I(dt, dW, dZ, alg::JDiagonal_oop, p = nothing, c = 1, γ = 1//1)
-    1//2 .* dW .* dW
+function get_iterated_I(dt, dW, dZ, alg::JDiagonal_oop, p = nothing, c = 1, γ = 1 // 1)
+    return 1 // 2 .* dW .* dW
 end
 
-function get_iterated_I!(dt, dW, dZ, alg::JDiagonal_iip, p = nothing, c = 1, γ = 1//1)
+function get_iterated_I!(dt, dW, dZ, alg::JDiagonal_iip, p = nothing, c = 1, γ = 1 // 1)
     (; J) = alg
     if dW isa Number
-        alg.J = 1//2 .* dW .^ 2
+        alg.J = 1 // 2 .* dW .^ 2
     else
-        @.. J = 1//2 * dW^2
+        @.. J = 1 // 2 * dW^2
     end
     return nothing
 end
 
-function get_iterated_I(dt, dW, dZ, alg::JCommute_oop, p = nothing, c = 1, γ = 1//1)
-    J = 1//2 .* vec(dW) .* vec(dW)'
-    J
+function get_iterated_I(dt, dW, dZ, alg::JCommute_oop, p = nothing, c = 1, γ = 1 // 1)
+    J = 1 // 2 .* vec(dW) .* vec(dW)'
+    return J
 end
 
-function get_iterated_I!(dt, dW, dZ, alg::JCommute_iip, p = nothing, c = 1, γ = 1//1)
+function get_iterated_I!(dt, dW, dZ, alg::JCommute_iip, p = nothing, c = 1, γ = 1 // 1)
     (; J) = alg
     mul!(J, vec(dW), vec(dW)')
-    @.. J *= 1//2
+    @.. J *= 1 // 2
     return nothing
 end
 
-# algs from LevyArea.jl # LevyArea.levyarea allocates random variables and then mutates these, see e.g. 
+# algs from LevyArea.jl # LevyArea.levyarea allocates random variables and then mutates these, see e.g.
 # https://github.com/stochastics-uni-luebeck/LevyArea.jl/blob/68c5cb08ab103b4dcd3178651f7a5dd9ce8c666d/src/milstein.jl#L25
-function get_iterated_I(dt, dW, dZ, alg::LevyArea.AbstractIteratedIntegralAlgorithm,
-        p = nothing, c = 1, γ = 1//1)
+function get_iterated_I(
+        dt, dW, dZ, alg::LevyArea.AbstractIteratedIntegralAlgorithm,
+        p = nothing, c = 1, γ = 1 // 1
+    )
     if isnothing(p)
-        ε = c * dt^(γ + 1//2)
+        ε = c * dt^(γ + 1 // 2)
         p = terms_needed(length(dW), dt, ε, alg, MaxL2())
     end
     I = LevyArea.levyarea(dW / √dt, p, alg)
-    I .= 1//2 * dW .* dW' .+ dt .* I
+    return I .= 1 // 2 * dW .* dW' .+ dt .* I
 end
 
 mutable struct IteratedIntegralAlgorithm_iip{JType, levyalgType} <:
-               LevyArea.AbstractIteratedIntegralAlgorithm
+    LevyArea.AbstractIteratedIntegralAlgorithm
     J::JType
     levyalg::levyalgType
     function IteratedIntegralAlgorithm_iip(ΔW, levyalg)
         J = false .* vec(ΔW) .* vec(ΔW)'
-        new{typeof(J), typeof(levyalg)}(J, levyalg)
+        return new{typeof(J), typeof(levyalg)}(J, levyalg)
     end
 end
 
 function get_iterated_I!(
-        dt, dW, dZ, alg::IteratedIntegralAlgorithm_iip, p = nothing, c = 1, γ = 1//1)
+        dt, dW, dZ, alg::IteratedIntegralAlgorithm_iip, p = nothing, c = 1, γ = 1 // 1
+    )
     (; J, levyalg) = alg
     if isnothing(p)
-        ε = c * dt^(γ + 1//2)
+        ε = c * dt^(γ + 1 // 2)
         p = terms_needed(length(dW), dt, ε, levyalg, MaxL2())
     end
     J .= LevyArea.levyarea(dW / √dt, p, levyalg)
-    J .= 1//2 * dW .* dW' .+ dt .* J
+    J .= 1 // 2 * dW .* dW' .+ dt .* J
     return nothing
 end
 
 # Default algorithms, keep KPWJ_oop() to have a non-mutating version
 function get_Jalg(ΔW, dt, prob, alg)
-    if alg.ii_approx isa IILevyArea
+    return if alg.ii_approx isa IILevyArea
         if isinplace(prob)
             if ΔW isa Number || is_diagonal_noise(prob)
                 return JDiagonal_iip(ΔW)
