@@ -1,10 +1,10 @@
 function verify_f2(f, p, q, pa, t, integrator, ::BAOABConstantCache)
     res = f(p, q, pa, t)
-    res != p && throwex(integrator)
+    return res != p && throwex(integrator)
 end
 function verify_f2(f, res, p, q, pa, t, integrator, ::BAOABCache)
     f(res, p, q, pa, t)
-    res != p && throwex(integrator)
+    return res != p && throwex(integrator)
 end
 function throwex(integrator)
     algn = typeof(integrator.alg)
@@ -17,7 +17,7 @@ function initialize!(integrator, cache::BAOABConstantCache)
     u1 = integrator.uprev.x[2]
 
     verify_f2(integrator.f.f2, du1, u1, p, t, integrator, cache)
-    cache.k = integrator.f.f1(du1, u1, p, t)
+    return cache.k = integrator.f.f1(du1, u1, p, t)
 end
 
 function initialize!(integrator, cache::BAOABCache)
@@ -26,7 +26,7 @@ function initialize!(integrator, cache::BAOABCache)
     u1 = integrator.uprev.x[2]
 
     verify_f2(integrator.f.f2, cache.k, du1, u1, p, t, integrator, cache)
-    integrator.f.f1(cache.k, du1, u1, p, t)
+    return integrator.f.f1(cache.k, du1, u1, p, t)
 end
 
 @muladd function perform_step!(integrator, cache::BAOABConstantCache)
@@ -36,21 +36,21 @@ end
     u1 = uprev.x[2]
 
     # B
-    du2 = du1 + half*dt*cache.k
+    du2 = du1 + half * dt * cache.k
 
     # A
-    u2 = u1 + half*dt*du2
+    u2 = u1 + half * dt * du2
 
     # O
-    noise = integrator.g(u2, p, t+dt*half) .* W.dW
-    du3 = c1*du2 + c2*noise
+    noise = integrator.g(u2, p, t + dt * half) .* W.dW
+    du3 = c1 * du2 + c2 * noise
 
     # A
-    u = u2 + half*dt*du3
+    u = u2 + half * dt * du3
 
     # B
-    cache.k = f.f1(du3, u, p, t+dt)
-    du = du3 + half*dt*cache.k
+    cache.k = f.f1(du3, u, p, t + dt)
+    du = du3 + half * dt * cache.k
 
     integrator.u = ArrayPartition((du, u))
 end
@@ -62,20 +62,20 @@ end
     u1 = uprev.x[2]
 
     # B
-    @.. dutmp = du1 + half*dt*k
+    @.. dutmp = du1 + half * dt * k
 
     # A
-    @.. utmp = u1 + half*dt*dutmp
+    @.. utmp = u1 + half * dt * dutmp
 
     # O
-    integrator.g(gtmp, utmp, p, t+dt*half)
-    @.. noise = gtmp*W.dW
-    @.. dutmp = c1*dutmp + c2*noise
+    integrator.g(gtmp, utmp, p, t + dt * half)
+    @.. noise = gtmp * W.dW
+    @.. dutmp = c1 * dutmp + c2 * noise
 
     # A
-    @.. u.x[2] = utmp + half*dt*dutmp
+    @.. u.x[2] = utmp + half * dt * dutmp
 
     # B
-    f.f1(k, dutmp, u.x[2], p, t+dt)
-    @.. u.x[1] = dutmp + half*dt*k
+    f.f1(k, dutmp, u.x[2], p, t + dt)
+    @.. u.x[1] = dutmp + half * dt * k
 end
