@@ -7,7 +7,7 @@ mutable struct RHS_IIF1M_Scalar{F, CType, tType, P} <: Function
 end
 
 function (f::RHS_IIF1M_Scalar)(resid, u)
-    resid[1] = u[1] - f.tmp - f.dt*f.f.f2(u[1], f.p, f.t+f.dt)[1]
+    return resid[1] = u[1] - f.tmp - f.dt * f.f.f2(u[1], f.p, f.t + f.dt)[1]
 end
 
 mutable struct RHS_IIF2M_Scalar{F, CType, tType, P} <: Function
@@ -19,18 +19,22 @@ mutable struct RHS_IIF2M_Scalar{F, CType, tType, P} <: Function
 end
 
 function (f::RHS_IIF2M_Scalar)(resid, u)
-    resid[1] = u[1] - f.tmp - 0.5f.dt*f.f.f2(u[1], f.p, f.t+f.dt)[1]
+    return resid[1] = u[1] - f.tmp - 0.5f.dt * f.f.f2(u[1], f.p, f.t + f.dt)[1]
 end
 
 @muladd function initialize!(
         integrator, cache::Union{
-            IIF1MConstantCache, IIF2MConstantCache, IIF1MilConstantCache})
+            IIF1MConstantCache, IIF2MConstantCache, IIF1MilConstantCache,
+        }
+    )
     cache.uhold[1] = integrator.uprev
 end
 
 @muladd function perform_step!(
         integrator, cache::Union{
-            IIF1MConstantCache, IIF2MConstantCache, IIF1MilConstantCache})
+            IIF1MConstantCache, IIF2MConstantCache, IIF1MilConstantCache,
+        }
+    )
     (; t, dt, uprev, u, W, p, f) = integrator
     (; uhold, rhs, nl_rhs) = cache
     alg = unwrap_alg(integrator, true)
@@ -38,13 +42,13 @@ end
     if cache isa IIF1MilConstantCache
         error("Milstein correction does not work.")
     elseif cache isa IIF1MConstantCache
-        tmp = exp(A*dt)*(uprev + integrator.g(uprev, p, t)*W.dW)
+        tmp = exp(A * dt) * (uprev + integrator.g(uprev, p, t) * W.dW)
     elseif cache isa IIF2MConstantCache
-        tmp = exp(A*dt)*(uprev + 0.5dt*integrator.f.f2(uprev, p, t) + integrator.g(uprev, p, t)*W.dW)
+        tmp = exp(A * dt) * (uprev + 0.5dt * integrator.f.f2(uprev, p, t) + integrator.g(uprev, p, t) * W.dW)
     end
 
     if integrator.iter > 1 && !integrator.u_modified
-        uhold[1] = current_extrapolant(t+dt, integrator)
+        uhold[1] = current_extrapolant(t + dt, integrator)
     end # else uhold is previous value.
 
     rhs.t = t
@@ -68,8 +72,8 @@ end
 function (f::RHS_IIF1)(resid, u)
     _du = get_du(f.dual_cache, eltype(u))
     du = reinterpret(eltype(u), _du)
-    f.f.f2(du, reshape(u, f.sizeu), f.p, f.t+f.dt)
-    @.. resid = u - f.tmp - f.dt*du
+    f.f.f2(du, reshape(u, f.sizeu), f.p, f.t + f.dt)
+    return @.. resid = u - f.tmp - f.dt * du
 end
 
 mutable struct RHS_IIF2{F, uType, tType, DiffCacheType, SizeType, P} <: Function
@@ -84,8 +88,8 @@ end
 function (f::RHS_IIF2)(resid, u)
     _du = get_du(f.dual_cache, eltype(u))
     du = reinterpret(eltype(u), _du)
-    f.f.f2(du, reshape(u, f.sizeu), f.p, f.t+f.dt)
-    @.. resid = u - f.tmp - 0.5f.dt*du
+    f.f.f2(du, reshape(u, f.sizeu), f.p, f.t + f.dt)
+    return @.. resid = u - f.tmp - 0.5f.dt * du
 end
 
 @muladd function perform_step!(integrator, cache::Union{IIF1MCache, IIF2MCache})
@@ -112,11 +116,11 @@ end
     end
 
     A = integrator.f.f1(rtmp1, uprev, p, t)
-    M = exp(A*dt)
+    M = exp(A * dt)
     mul!(tmp, M, rtmp3)
 
     if integrator.iter > 1 && !integrator.u_modified
-        current_extrapolant!(uhold, t+dt, integrator)
+        current_extrapolant!(uhold, t + dt, integrator)
     end # else uhold is previous value.
 
     rhs.t = t
@@ -134,13 +138,13 @@ end
     (; t, dt, uprev, u, W, p, f) = integrator
     alg = unwrap_alg(integrator, true)
 
-    dW = W.dW;
+    dW = W.dW
     sqdt = integrator.sqdt
-    f = integrator.f;
+    f = integrator.f
     g = integrator.g
 
     A = integrator.f.f1(t, uprev, rtmp1)
-    M = exp(A*dt)
+    M = exp(A * dt)
 
     uidx = eachindex(u)
     integrator.g(rtmp2, uprev, p, t)
@@ -151,26 +155,26 @@ end
             mul!(rtmp3, rtmp2, W.dW)
         end
     else #Milstein correction
-        rtmp2 = M*rtmp2 # mul!(rtmp2,M,gtmp)
+        rtmp2 = M * rtmp2 # mul!(rtmp2,M,gtmp)
         (; gtmp, gtmp2) = cache
         #error("Milstein correction does not work.")
         mul!(rtmp3, rtmp2, W.dW)
-        I = zeros(length(dW), length(dW));
-        Dg = zeros(length(dW), length(dW));
+        I = zeros(length(dW), length(dW))
+        Dg = zeros(length(dW), length(dW))
         mil_correction = zeros(length(dW))
         mil_correction .= 0.0
         for i in 1:length(dW), j in 1:length(dW)
 
-            I[j, i] = 0.5*dW[i]*dW[j]
-            j == i && (I[i, i] -= 0.5*dt) # Ito correction
+            I[j, i] = 0.5 * dW[i] * dW[j]
+            j == i && (I[i, i] -= 0.5 * dt) # Ito correction
         end
         for j in 1:length(uprev)
             #Kj = uprev .+ dt.*du1 + sqdt*rtmp2[:,j] # This works too
-            Kj = uprev .+ sqdt*rtmp2[:, j]
-            g(gtmp, Kj, p, t);
+            Kj = uprev .+ sqdt * rtmp2[:, j]
+            g(gtmp, Kj, p, t)
             mul!(gtmp2, M, gtmp)
-            Dgj = (gtmp2 - rtmp2)/sqdt
-            mil_correction .+= Dgj*I[:, j]
+            Dgj = (gtmp2 - rtmp2) / sqdt
+            mil_correction .+= Dgj * I[:, j]
         end
         rtmp3 .+= mil_correction
     end
@@ -189,7 +193,7 @@ end
     end
 
     if integrator.iter > 1 && !integrator.u_modified
-        current_extrapolant!(uhold, t+dt, integrator)
+        current_extrapolant!(uhold, t + dt, integrator)
     end # else uhold is previous value.
 
     rhs.t = t
