@@ -1,5 +1,8 @@
-@muladd function perform_step!(integrator, cache::Union{
-        ISSEMConstantCache, ISSEulerHeunConstantCache})
+@muladd function perform_step!(
+        integrator, cache::Union{
+            ISSEMConstantCache, ISSEulerHeunConstantCache,
+        }
+    )
     (; t, dt, uprev, u, p, f) = integrator
     (; nlsolver) = cache
     alg = unwrap_alg(integrator, true)
@@ -22,7 +25,9 @@
     end
     nlsolver.z = z
 
-    nlsolver.c = a
+    # nlsolver.c should be the Butcher tableau coefficient (time fraction), not coefficient*dt
+    # OrdinaryDiffEqNonlinearSolve computes tstep = t + c * dt, so c should be in [0,1]
+    nlsolver.c = alg.symplectic ? one(t) / 2 : theta
     if alg.symplectic
         # u = uprev + z then  u = (uprev+u)/2 = (uprev+uprev+z)/2 = uprev + z/2
         #u = uprev + z/2
@@ -100,9 +105,11 @@
             end
         end
 
-        resids = calculate_residuals(Ed, En, uprev, u, integrator.opts.abstol,
+        resids = calculate_residuals(
+            Ed, En, uprev, u, integrator.opts.abstol,
             integrator.opts.reltol, integrator.opts.delta,
-            integrator.opts.internalnorm, t)
+            integrator.opts.internalnorm, t
+        )
         integrator.EEst = integrator.opts.internalnorm(resids, t)
     end
 
@@ -125,7 +132,7 @@ end
     repeat_step = false
 
     if integrator.success_iter > 0 && !integrator.u_modified &&
-       alg.extrapolant == :interpolant
+            alg.extrapolant == :interpolant
         current_extrapolant!(u, t + dt, integrator)
     elseif alg.extrapolant == :linear
         @.. u = uprev + integrator.fsalfirst * dt
@@ -214,7 +221,9 @@ end
         #@.. u = uprev + dt*(1-theta)*tmp + theta*z
         @.. tmp = uprev + dt * (1 - theta) * tmp
     end
-    nlsolver.c = a
+    # nlsolver.c should be the Butcher tableau coefficient (time fraction), not coefficient*dt
+    # OrdinaryDiffEqNonlinearSolve computes tstep = t + c * dt, so c should be in [0,1]
+    nlsolver.c = alg.symplectic ? one(t) / 2 : theta
     z = OrdinaryDiffEqNonlinearSolve.nlsolve!(nlsolver, integrator, cache, repeat_step)
     OrdinaryDiffEqNonlinearSolve.nlsolvefail(nlsolver) && return
 
@@ -241,9 +250,11 @@ end
 
     ##############################################################################
     if integrator.opts.adaptive
-        calculate_residuals!(tmp, k, dz, uprev, u, integrator.opts.abstol,
+        calculate_residuals!(
+            tmp, k, dz, uprev, u, integrator.opts.abstol,
             integrator.opts.reltol, integrator.opts.delta,
-            integrator.opts.internalnorm, t)
+            integrator.opts.internalnorm, t
+        )
         integrator.EEst = integrator.opts.internalnorm(tmp, t)
     end
 end
