@@ -1,16 +1,20 @@
 @muladd function perform_step!(integrator, cache::SKenCarpConstantCache)
     (; t, dt, uprev, u, g, p, f) = integrator
     (; nlsolver) = cache
-    (; γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31,
-    α32) = cache.tab
-    (; ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4,
-    ebtilde1, ebtilde2, ebtilde3, ebtilde4) = cache.tab
+    (;
+        γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31,
+        α32,
+    ) = cache.tab
+    (;
+        ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4,
+        ebtilde1, ebtilde2, ebtilde3, ebtilde4,
+    ) = cache.tab
     (; nb021, nb043) = cache.tab
     alg = unwrap_alg(integrator, true)
     OrdinaryDiffEqNonlinearSolve.markfirststage!(nlsolver)
 
     sqrt3 = sqrt(3one(eltype(integrator.W.dW)))
-    chi2 = (integrator.W.dW + integrator.W.dZ/sqrt3)/2 #I_(1,0)/h
+    chi2 = (integrator.W.dW + integrator.W.dZ / sqrt3) / 2 #I_(1,0)/h
 
     if integrator.f isa SplitSDEFunction
         f = integrator.f.f1
@@ -20,20 +24,20 @@
     end
 
     # precalculations
-    γdt = γ*dt
+    γdt = γ * dt
 
     # calculate W
     repeat_step = false
 
-    z₁ = dt*f(uprev, p, t)
+    z₁ = dt * f(uprev, p, t)
     nlsolver.c = 2γ
 
     g1 = g(uprev, p, t)
-    tmp = uprev + γ*z₁ + nb021*chi2 .* g1
+    tmp = uprev + γ * z₁ + nb021 * chi2 .* g1
     if integrator.f isa SplitSDEFunction
         # This assumes the implicit part is cheaper than the explicit part
-        k1 = dt*f2(uprev, p, t)
-        tmp += ea21*k1
+        k1 = dt * f2(uprev, p, t)
+        tmp += ea21 * k1
     end
     nlsolver.tmp = tmp
 
@@ -51,11 +55,11 @@
 
     nlsolver.c = c3
     if integrator.f isa SplitSDEFunction
-        u = tmp + γ*z₂
-        k2 = dt*f2(u, p, t + 2γ*dt)
-        tmp = uprev + a31*z₁ + a32*z₂ + ea31*k1 + ea32*k2
+        u = tmp + γ * z₂
+        k2 = dt * f2(u, p, t + 2γ * dt)
+        tmp = uprev + a31 * z₁ + a32 * z₂ + ea31 * k1 + ea32 * k2
     else
-        tmp = uprev + a31*z₁ + a32*z₂
+        tmp = uprev + a31 * z₁ + a32 * z₂
     end
     nlsolver.tmp = tmp
 
@@ -76,12 +80,12 @@
     # Note: Can use g1 since c13 = 0 => g3 == g1
 
     if integrator.f isa SplitSDEFunction
-        u = tmp + γ*z₃
-        k3 = dt*f2(u, p, t + c3*dt)
-        tmp = uprev + a41*z₁ + a42*z₂ + a43*z₃ + ea41*k1 + ea42*k2 + ea43*k3 +
-              nb043*chi2 .* g1
+        u = tmp + γ * z₃
+        k3 = dt * f2(u, p, t + c3 * dt)
+        tmp = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + ea41 * k1 + ea42 * k2 + ea43 * k3 +
+            nb043 * chi2 .* g1
     else
-        tmp = uprev + a41*z₁ + a42*z₂ + a43*z₃ + nb043*chi2 .* g1
+        tmp = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + nb043 * chi2 .* g1
     end
     nlsolver.tmp = tmp
 
@@ -95,17 +99,17 @@
     z₄ = OrdinaryDiffEqNonlinearSolve.nlsolve!(nlsolver, integrator, cache, repeat_step)
     OrdinaryDiffEqNonlinearSolve.nlsolvefail(nlsolver) && return
 
-    u = tmp + γ*z₄
-    g4 = g(uprev, p, t+dt)
+    u = tmp + γ * z₄
+    g4 = g(uprev, p, t + dt)
 
-    E₂ = chi2 .* (g1-g4)
+    E₂ = chi2 .* (g1 - g4)
 
     if integrator.f isa SplitSDEFunction
-        k4 = dt*f2(u, p, t+dt)
-        u = uprev + a41*z₁ + a42*z₂ + a43*z₃ + γ*z₄ + eb1*k1 + eb2*k2 + eb3*k3 + eb4*k4 +
+        k4 = dt * f2(u, p, t + dt)
+        u = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + γ * z₄ + eb1 * k1 + eb2 * k2 + eb3 * k3 + eb4 * k4 +
             integrator.W.dW .* g4 + E₂
     else
-        u = uprev + a41*z₁ + a42*z₂ + a43*z₃ + γ*z₄ + integrator.W.dW .* g4 + E₂
+        u = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + γ * z₄ + integrator.W.dW .* g4 + E₂
     end
 
     ################################### Finalize
@@ -113,15 +117,16 @@
     if integrator.opts.adaptive
         if alg.ode_error_est
             if integrator.f isa SplitSDEFunction
-                tmp = btilde1*z₁ + btilde2*z₂ + btilde3*z₃ + btilde4*z₄ + ebtilde1*k1 +
-                      ebtilde2*k2 + ebtilde3*k3 + ebtilde4*k4 + chi2*(g1-g4)
+                tmp = btilde1 * z₁ + btilde2 * z₂ + btilde3 * z₃ + btilde4 * z₄ + ebtilde1 * k1 +
+                    ebtilde2 * k2 + ebtilde3 * k3 + ebtilde4 * k4 + chi2 * (g1 - g4)
             else
-                tmp = btilde1*z₁ + btilde2*z₂ + btilde3*z₃ + btilde4*z₄ + chi2*(g1-g4)
+                tmp = btilde1 * z₁ + btilde2 * z₂ + btilde3 * z₃ + btilde4 * z₄ + chi2 * (g1 - g4)
             end
             if alg.smooth_est # From Shampine
                 E₁ = DiffEqBase._reshape(
                     OrdinaryDiffEqDifferentiation.get_W(nlsolver) \ DiffEqBase._vec(tmp),
-                    axes(tmp))
+                    axes(tmp)
+                )
             else
                 E₁ = tmp
             end
@@ -129,9 +134,11 @@
             E₁ = z₁ + z₂ + z₃ + z₄
         end
 
-        resids = calculate_residuals(E₁, E₂, uprev, u, integrator.opts.abstol,
+        resids = calculate_residuals(
+            E₁, E₂, uprev, u, integrator.opts.abstol,
             integrator.opts.reltol, integrator.opts.delta,
-            integrator.opts.internalnorm, t)
+            integrator.opts.internalnorm, t
+        )
         integrator.EEst = integrator.opts.internalnorm(resids, t)
     end
 
@@ -144,8 +151,10 @@ end
     (; g1, g4, chi2, nlsolver) = cache
     (; z, tmp) = nlsolver
     (; k, dz) = nlsolver.cache # alias to reduce memory
-    (; γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31,
-    α32) = cache.tab
+    (;
+        γ, a31, a32, a41, a42, a43, btilde1, btilde2, btilde3, btilde4, c3, α31,
+        α32,
+    ) = cache.tab
     (; ea21, ea31, ea32, ea41, ea42, ea43, eb1, eb2, eb3, eb4) = cache.tab
     (; ebtilde1, ebtilde2, ebtilde3, ebtilde4) = cache.tab
     (; nb021, nb043) = cache.tab
@@ -168,14 +177,14 @@ end
 
     sqrt3 = sqrt(3one(eltype(integrator.W.dW)))
     if integrator.W.dW isa Union{SArray, Number}
-        chi2 = (integrator.W.dW + integrator.W.dZ/sqrt3)/2 #I_(1,0)/h
+        chi2 = (integrator.W.dW + integrator.W.dZ / sqrt3) / 2 #I_(1,0)/h
     else
-        @.. chi2 = (integrator.W.dW + integrator.W.dZ/sqrt3)/2 #I_(1,0)/h
+        @.. chi2 = (integrator.W.dW + integrator.W.dZ / sqrt3) / 2 #I_(1,0)/h
     end
 
     # precalculations
 
-    γdt = γ*dt
+    γdt = γ * dt
 
     if !repeat_step && !integrator.last_stepfail
         f(z₁, integrator.uprev, p, integrator.t)
@@ -188,12 +197,12 @@ end
     g(g1, uprev, p, t)
 
     if is_diagonal_noise(integrator.sol.prob)
-        @.. z₄ = chi2*g1 # use z₄ as storage for the g1*chi2
+        @.. z₄ = chi2 * g1 # use z₄ as storage for the g1*chi2
     else
         mul!(z₄, g1, chi2) # use z₄ as storage for the g1*chi2
     end
 
-    @.. tmp = uprev + γ*z₁ + nb021*z₄
+    @.. tmp = uprev + γ * z₁ + nb021 * z₄
 
     if alg.extrapolant == :min_correct
         @.. z₂ = zero(eltype(dz))
@@ -207,7 +216,7 @@ end
             f2(k1, integrator.uprev, integrator.p, integrator.t)
             k1 .*= dt
         end
-        @.. tmp += ea21*k1
+        @.. tmp += ea21 * k1
     end
 
     nlsolver.z = z₂
@@ -220,12 +229,12 @@ end
     ################################## Solve Step 3
 
     if integrator.f isa SplitSDEFunction
-        @.. u = tmp + γ*z₂
-        f2(k2, u, p, t + 2γ*dt);
+        @.. u = tmp + γ * z₂
+        f2(k2, u, p, t + 2γ * dt)
         k2 .*= dt
-        @.. tmp = uprev + a31*z₁ + a32*z₂ + ea31*k1 + ea32*k2
+        @.. tmp = uprev + a31 * z₁ + a32 * z₂ + ea31 * k1 + ea32 * k2
     else
-        @.. tmp = uprev + a31*z₁ + a32*z₂
+        @.. tmp = uprev + a31 * z₁ + a32 * z₂
     end
 
     if alg.extrapolant == :min_correct
@@ -241,15 +250,15 @@ end
     ################################## Solve Step 4
 
     if integrator.f isa SplitSDEFunction
-        @.. u = tmp + γ*z₃
-        f2(k3, u, p, t + c3*dt);
+        @.. u = tmp + γ * z₃
+        f2(k3, u, p, t + c3 * dt)
         k3 .*= dt
         # z₄ is storage for the g1*chi2 from earlier
-        @.. tmp = uprev + a41*z₁ + a42*z₂ + a43*z₃ + ea41*k1 + ea42*k2 + ea43*k3 + nb043*z₄
+        @.. tmp = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + ea41 * k1 + ea42 * k2 + ea43 * k3 + nb043 * z₄
     else
         (; α41, α42) = cache.tab
         # z₄ is storage for the g1*chi2
-        @.. tmp = uprev + a41*z₁ + a42*z₂ + a43*z₃ + nb043*z₄
+        @.. tmp = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + nb043 * z₄
     end
 
     if alg.extrapolant == :min_correct
@@ -263,32 +272,32 @@ end
     z₄ = OrdinaryDiffEqNonlinearSolve.nlsolve!(nlsolver, integrator, cache, repeat_step)
     OrdinaryDiffEqNonlinearSolve.nlsolvefail(nlsolver) && return
 
-    g(g4, u, p, t+dt)
+    g(g4, u, p, t + dt)
 
     if integrator.f isa SplitSDEFunction
-        @.. u = tmp + γ*z₄
-        f2(k4, u, p, t+dt);
+        @.. u = tmp + γ * z₄
+        f2(k4, u, p, t + dt)
         k4 .*= dt
         if is_diagonal_noise(integrator.sol.prob)
-            @.. E₂ = chi2*(g1-g4)
-            @.. u = uprev + a41*z₁ + a42*z₂ + a43*z₃ + γ*z₄ + eb1*k1 + eb2*k2 + eb3*k3 +
-                    eb4*k4 + integrator.W.dW*g4 + E₂
+            @.. E₂ = chi2 * (g1 - g4)
+            @.. u = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + γ * z₄ + eb1 * k1 + eb2 * k2 + eb3 * k3 +
+                eb4 * k4 + integrator.W.dW * g4 + E₂
         else
             g1 .-= g4
             mul!(E₂, g1, chi2)
             mul!(tmp, g4, integrator.W.dW)
-            @.. u = uprev + a41*z₁ + a42*z₂ + a43*z₃ + γ*z₄ + eb1*k1 + eb2*k2 + eb3*k3 +
-                    eb4*k4 + tmp + E₂
+            @.. u = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + γ * z₄ + eb1 * k1 + eb2 * k2 + eb3 * k3 +
+                eb4 * k4 + tmp + E₂
         end
     else
         if is_diagonal_noise(integrator.sol.prob)
-            @.. E₂ = chi2*(g1-g4)
-            @.. u = uprev + a41*z₁ + a42*z₂ + a43*z₃ + γ*z₄ + integrator.W.dW*g4 + E₂
+            @.. E₂ = chi2 * (g1 - g4)
+            @.. u = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + γ * z₄ + integrator.W.dW * g4 + E₂
         else
             g1 .-= g4
             mul!(E₂, g1, chi2)
             mul!(tmp, g4, integrator.W.dW)
-            @.. u = uprev + a41*z₁ + a42*z₂ + a43*z₃ + γ*z₄ + tmp + E₂
+            @.. u = uprev + a41 * z₁ + a42 * z₂ + a43 * z₃ + γ * z₄ + tmp + E₂
         end
     end
 
@@ -297,16 +306,17 @@ end
     if integrator.opts.adaptive
         if alg.ode_error_est
             if integrator.f isa SplitSDEFunction
-                @.. g1 = btilde1*z₁ + btilde2*z₂ + btilde3*z₃ + btilde4*z₄ + ebtilde1*k1 +
-                         ebtilde2*k2 + ebtilde3*k3 + ebtilde4*k4
+                @.. g1 = btilde1 * z₁ + btilde2 * z₂ + btilde3 * z₃ + btilde4 * z₄ + ebtilde1 * k1 +
+                    ebtilde2 * k2 + ebtilde3 * k3 + ebtilde4 * k4
             else
-                @.. g1 = btilde1*z₁ + btilde2*z₂ + btilde3*z₃ + btilde4*z₄
+                @.. g1 = btilde1 * z₁ + btilde2 * z₂ + btilde3 * z₃ + btilde4 * z₄
             end
             if alg.smooth_est # From Shampine
                 linres = OrdinaryDiffEqDifferentiation.dolinsolve(
                     integrator, nlsolver.cache.linsolve;
                     b = DiffEqBase._vec(g1),
-                    linu = DiffEqBase._vec(E₁))
+                    linu = DiffEqBase._vec(E₁)
+                )
             else
                 E₁ .= dz
             end
@@ -314,9 +324,11 @@ end
             @.. E₁ = z₁ + z₂ + z₃ + z₄
         end
 
-        calculate_residuals!(tmp, E₁, E₂, uprev, u, integrator.opts.abstol,
+        calculate_residuals!(
+            tmp, E₁, E₂, uprev, u, integrator.opts.abstol,
             integrator.opts.reltol, integrator.opts.delta,
-            integrator.opts.internalnorm, t)
+            integrator.opts.internalnorm, t
+        )
         integrator.EEst = integrator.opts.internalnorm(tmp, t)
     end
 end
