@@ -3,24 +3,24 @@ using Random
 
 function brusselator_f!(du, u, p, t)
     @inbounds begin
-        du[1] = (p[1]-1)*u[1]+p[1]*u[1]^2+(u[1]+1)^2*u[2]
-        du[2] = -p[1]*u[1]-p[1]*u[1]^2-(u[1]+1)^2*u[2]
+        du[1] = (p[1] - 1) * u[1] + p[1] * u[1]^2 + (u[1] + 1)^2 * u[2]
+        du[2] = -p[1] * u[1] - p[1] * u[1]^2 - (u[1] + 1)^2 * u[2]
     end
-    nothing
+    return nothing
 end
 
 function scalar_noise!(du, u, p, t)
     @inbounds begin
-        du[1] = p[2]*u[1]*(1+u[1])
-        du[2] = -p[2]*u[1]*(1+u[1])
+        du[1] = p[2] * u[1] * (1 + u[1])
+        du[2] = -p[2] * u[1] * (1 + u[1])
     end
-    nothing
+    return nothing
 end
 
 function prob_func(prob, i, repeat)
     Random.seed!(seeds[i])
     W = WienerProcess(0.0, 0.0, 0.0)
-    remake(prob, noise = W)
+    return remake(prob, noise = W)
 end
 
 # fix seeds
