@@ -3,7 +3,7 @@ using SDEProblemLibrary: prob_sde_stiffquadito
 
 Random.seed!(100)
 prob = prob_sde_stiffquadito
-prob = remake(prob; p = (1e5, 2.0))
+prob = remake(prob; p = (1.0e5, 2.0))
 alg = AutoSOSRA2(SKenCarp(), maxstiffstep = 5, maxnonstiffstep = 2, stiffalgfirst = false)
 @test StochasticDiffEq.isadaptive(prob, alg)
 @test StochasticDiffEq.isadaptive(alg)
@@ -13,7 +13,8 @@ alg = AutoSOSRA2(SKenCarp(), maxstiffstep = 5, maxnonstiffstep = 2, stiffalgfirs
 
 Random.seed!(100)
 prob = prob_sde_stiffquadito
-prob = remake(prob; p = (1e5, 2.0))
+prob = remake(prob; p = (1.0e5, 2.0))
 @time sol = solve(
-    prob, AutoSOSRI2(ImplicitRKMil(), maxstiffstep = 1, maxnonstiffstep = 10, stiffalgfirst = false))
+    prob, AutoSOSRI2(ImplicitRKMil(), maxstiffstep = 1, maxnonstiffstep = 10, stiffalgfirst = false)
+)
 @test length(unique(sol.alg_choice)) == 2
