@@ -12,7 +12,7 @@ using Random
 using DiffEqDevTools
 seed = 103473
 function prob_func(prob, i, repeat)
-    remake(prob, seed = seeds[i])
+    return remake(prob, seed = seeds[i])
 end
 
 """
@@ -21,7 +21,7 @@ end
 
 @info "Scalar noise"
 
-numtraj = Int(2e6) # in the paper they use 1e9
+numtraj = Int(2.0e6) # in the paper they use 1e9
 u₀ = 0.0
 f(u, p, t) = 1 // 2 * u + sqrt(u^2 + 1)
 g(u, p, t) = sqrt(u^2 + 1)
@@ -36,12 +36,14 @@ Random.seed!(seed)
 seeds = rand(UInt, numtraj)
 
 prob = SDEProblem(f, g, u₀, tspan)
-ensemble_prob = EnsembleProblem(prob;
+ensemble_prob = EnsembleProblem(
+    prob;
     output_func = (sol, i) -> (h1(asinh(sol.u[end])), false),
     prob_func = prob_func
 )
 
-sim = test_convergence(dts, ensemble_prob, W2Ito1(),
+sim = test_convergence(
+    dts, ensemble_prob, W2Ito1(),
     save_everystep = false, trajectories = numtraj, save_start = false, adaptive = false,
     weak_timeseries_errors = false, weak_dense_errors = false,
     expected_value = 0.0
@@ -53,10 +55,10 @@ println("W2Ito1:", sim.𝒪est[:weak_final])
 
 u₀ = [0.1, 0.1]
 function f2(u, p, t)
-    [3 // 2 * u[1], 3 // 2 * u[2]]
+    return [3 // 2 * u[1], 3 // 2 * u[2]]
 end
 function g2(u, p, t)
-    [1 // 10 * u[1], 1 // 10 * u[2]]
+    return [1 // 10 * u[1], 1 // 10 * u[2]]
 end
 dts = 1 .// 2 .^ (3:-1:0)
 tspan = (0.0, 1.0)
@@ -64,16 +66,18 @@ tspan = (0.0, 1.0)
 h2(z) = z^2 # == 1//10**exp(3//2*t) if h3(z) = z and  == 1//100**exp(301//100*t) if h3(z) = z^2 )
 
 prob = SDEProblem(f2, g2, u₀, tspan)
-ensemble_prob = EnsembleProblem(prob;
+ensemble_prob = EnsembleProblem(
+    prob;
     output_func = (sol, i) -> (h2(sol.u[end][1]), false),
     prob_func = prob_func
 )
 
-numtraj = Int(1e5)
+numtraj = Int(1.0e5)
 Random.seed!(seed)
 seeds = rand(UInt, numtraj)
 
-sim = test_convergence(dts, ensemble_prob, W2Ito1(),
+sim = test_convergence(
+    dts, ensemble_prob, W2Ito1(),
     save_everystep = false, trajectories = numtraj, save_start = false, adaptive = false,
     weak_timeseries_errors = false, weak_dense_errors = false,
     expected_value = 1 // 100 * exp(301 // 100)
@@ -88,8 +92,10 @@ function f3(u, p, t)
     return [-273 // 512 * u[1], -1 // 160 * u[1] - (-785 // 512 + sqrt(2) / 8) * u[2]]
 end
 function g3(u, p, t)
-    [1 // 4 * u[1] 1 // 16 * u[1]
-     (1 - 2 * sqrt(2)) / 4 * u[1] 1 // 10 * u[1] + 1 // 16 * u[2]]
+    return [
+        1 // 4 * u[1] 1 // 16 * u[1]
+        (1 - 2 * sqrt(2)) / 4 * u[1] 1 // 10 * u[1] + 1 // 16 * u[2]
+    ]
 end
 dts = 1 .// 2 .^ (3:-1:0)
 tspan = (0.0, 3.0)
@@ -97,17 +103,19 @@ tspan = (0.0, 3.0)
 h3(z) = z^2 # but apply it only to u[1]
 
 prob = SDEProblem(f3, g3, u₀, tspan, noise_rate_prototype = zeros(2, 2))
-ensemble_prob = EnsembleProblem(prob;
+ensemble_prob = EnsembleProblem(
+    prob;
     output_func = (sol, i) -> (h3(sol.u[end][1]), false),
     prob_func = prob_func
 )
 
-numtraj = Int(1e6)
+numtraj = Int(1.0e6)
 seed = 100
 Random.seed!(seed)
 seeds = rand(UInt, numtraj)
 
-sim = test_convergence(dts, ensemble_prob, W2Ito1(),
+sim = test_convergence(
+    dts, ensemble_prob, W2Ito1(),
     save_everystep = false, trajectories = numtraj, save_start = false, adaptive = false,
     weak_timeseries_errors = false, weak_dense_errors = false,
     expected_value = exp(-3.0)
@@ -131,16 +139,18 @@ tspan = (0.0, 2.0)
 h1(z) = z^3 - 6 * z^2 + 8 * z
 
 prob = SDEProblem(f1!, g1!, u₀, tspan)
-ensemble_prob = EnsembleProblem(prob;
+ensemble_prob = EnsembleProblem(
+    prob;
     output_func = (sol, i) -> (h1(asinh(sol.u[end][1])), false),
     prob_func = prob_func
 )
 
-numtraj = Int(1e6)
+numtraj = Int(1.0e6)
 Random.seed!(seed)
 seeds = rand(UInt, numtraj)
 
-sim = test_convergence(dts, ensemble_prob, W2Ito1(),
+sim = test_convergence(
+    dts, ensemble_prob, W2Ito1(),
     save_everystep = false, trajectories = numtraj, save_start = false, adaptive = false,
     weak_timeseries_errors = false, weak_dense_errors = false,
     expected_value = 0.0
@@ -153,11 +163,11 @@ println("W2Ito1:", sim.𝒪est[:weak_final])
 u₀ = [0.1, 0.1]
 function f2!(du, u, p, t)
     du[1] = 3 // 2 * u[1]
-    du[2] = 3 // 2 * u[2]
+    return du[2] = 3 // 2 * u[2]
 end
 function g2!(du, u, p, t)
     du[1] = 1 // 10 * u[1]
-    du[2] = 1 // 10 * u[2]
+    return du[2] = 1 // 10 * u[2]
 end
 dts = 1 .// 2 .^ (3:-1:0)
 tspan = (0.0, 1.0)
@@ -165,16 +175,18 @@ tspan = (0.0, 1.0)
 h2(z) = z^2 # == 1//10**exp(3//2*t) if h3(z) = z and  == 1//100**exp(301//100*t) if h3(z) = z^2 )
 
 prob = SDEProblem(f2!, g2!, u₀, tspan)
-ensemble_prob = EnsembleProblem(prob;
+ensemble_prob = EnsembleProblem(
+    prob;
     output_func = (sol, i) -> (h2(sol.u[end][1]), false),
     prob_func = prob_func
 )
 
-numtraj = Int(1e5)
+numtraj = Int(1.0e5)
 Random.seed!(seed)
 seeds = rand(UInt, numtraj)
 
-sim = test_convergence(dts, ensemble_prob, W2Ito1(),
+sim = test_convergence(
+    dts, ensemble_prob, W2Ito1(),
     save_everystep = false, trajectories = numtraj, save_start = false, adaptive = false,
     weak_timeseries_errors = false, weak_dense_errors = false,
     expected_value = 1 // 100 * exp(301 // 100)
@@ -187,13 +199,13 @@ println("W2Ito1:", sim.𝒪est[:weak_final])
 u₀ = [1.0, 1.0]
 function f3!(du, u, p, t)
     du[1] = -273 // 512 * u[1]
-    du[2] = -1 // 160 * u[1] - (-785 // 512 + sqrt(2) / 8) * u[2]
+    return du[2] = -1 // 160 * u[1] - (-785 // 512 + sqrt(2) / 8) * u[2]
 end
 function g3!(du, u, p, t)
-    du[1, 1] = 1//4*u[1]
-    du[1, 2] = 1//16*u[1]
-    du[2, 1] = (1-2*sqrt(2))/4*u[1]
-    du[2, 2] = 1//10*u[1]+1//16*u[2]
+    du[1, 1] = 1 // 4 * u[1]
+    du[1, 2] = 1 // 16 * u[1]
+    du[2, 1] = (1 - 2 * sqrt(2)) / 4 * u[1]
+    return du[2, 2] = 1 // 10 * u[1] + 1 // 16 * u[2]
 end
 dts = 1 .// 2 .^ (3:-1:0)
 tspan = (0.0, 3.0)
@@ -201,17 +213,19 @@ tspan = (0.0, 3.0)
 h3(z) = z^2 # but apply it only to u[1]
 
 prob = SDEProblem(f3!, g3!, u₀, tspan, noise_rate_prototype = zeros(2, 2))
-ensemble_prob = EnsembleProblem(prob;
+ensemble_prob = EnsembleProblem(
+    prob;
     output_func = (sol, i) -> (h3(sol.u[end][1]), false),
     prob_func = prob_func
 )
 
-numtraj = Int(1e6)
+numtraj = Int(1.0e6)
 seed = 100
 Random.seed!(seed)
 seeds = rand(UInt, numtraj)
 
-sim = test_convergence(dts, ensemble_prob, W2Ito1(),
+sim = test_convergence(
+    dts, ensemble_prob, W2Ito1(),
     save_everystep = false, trajectories = numtraj, save_start = false, adaptive = false,
     weak_timeseries_errors = false, weak_dense_errors = false,
     expected_value = exp(-3.0)
